@@ -1,6 +1,6 @@
 package Simple::Factory;
 {
-    $Simple::Factory::VERSION = '0.06';
+    $Simple::Factory::VERSION = '0.07';
 }
 use strict;
 use warnings;
@@ -511,4 +511,4 @@ Tiago Peczenyj <tiago (dot) peczenyj (at) gmail (dot) com>
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website
-https://github.com/peczenyj/simple-factory-p5/issues
+L<https://github.com/peczenyj/simple-factory-p5/issues>
